User Documentation
==================

A word about documentation approach: There is no dedicated API documentation as such. SatMAD employs the
`Astropy <https://docs.astropy.org>`_ approach, where each package is introduced with its own API documentation
at the end.

Orbits and Trajectories
^^^^^^^^^^^^^^^^^^^^^^^
.. toctree::
   :maxdepth: 2

   propagation/tle
   coordinates/trajectory

Time and Coordinates
^^^^^^^^^^^^^^^^^^^^^
.. toctree::
   :maxdepth: 2

   utils/timeinterval
   coordinates/frames


Utilities
^^^^^^^^^^^^^^^^^
.. toctree::
   :maxdepth: 2

   utils/interpolators
